@@ -12,18 +12,19 @@ import pandas as pd
 
 from database.db_mongo import MongoDatabase
 from database.db_neo4j import Neo4jDatabase
-
+import utils.utils as utils
 
 class BI(object):
 
     def __init__(self, environment):
         self.environment = environment
+        self.utils = utils
         self.process_bi()
 
     def process_bi(self):
         self.open_database_connections()
 
-        self.products_df = self.get_dataframe_from_mongo()
+        self.products_df = self.utils.get_dataframe_from_mongo(self.mongo_conn)
 
         self.close_mongo_connection()
 
@@ -35,14 +36,6 @@ class BI(object):
         self.neo4j = Neo4jDatabase(self.environment)
         self.neo4j_conn = self.neo4j.connect()
 
-    def get_dataframe_from_mongo(self):
-        products_df = self.mongo_conn.db.df_products.find({}).sort('created', pymongo.DESCENDING)
-        
-        if products_df:
-            return pd.DataFrame(products_df[0]['df'])
-    
-        return ''
-
     def close_mongo_connection(self):
         self.mongo.close_connection()
 
